==> qt-creator-opensource-src-4.11.0.zip: qt-creator-opensource-src-4.11.0/src/plugins/texteditor/codeassist/functionhintproposal.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "functionhintproposal.h"
#include "ifunctionhintproposalmodel.h"
#include "functionhintproposalwidget.h"

using namespace TextEditor;

FunctionHintProposal::FunctionHintProposal(int cursorPos, FunctionHintProposalModelPtr model)
    : IAssistProposal(cursorPos)
    , m_model(model)
{
    setFragile(true);
}

FunctionHintProposal::~FunctionHintProposal() = default;

ProposalModelPtr FunctionHintProposal::model() const
{
    return m_model;
}

IAssistProposalWidget *FunctionHintProposal::createWidget() const
{
    return new FunctionHintProposalWidget;
}

==> qt-creator-opensource-src-8.0.2.zip: qt-creator-opensource-src-8.0.2/src/plugins/texteditor/codeassist/functionhintproposal.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "functionhintproposal.h"
#include "ifunctionhintproposalmodel.h"
#include "functionhintproposalwidget.h"

static const char functionHintId[] = "TextEditor.FunctionHintId";

using namespace TextEditor;

FunctionHintProposal::FunctionHintProposal(int cursorPos, FunctionHintProposalModelPtr model)
    : IAssistProposal(functionHintId, cursorPos)
    , m_model(model)
{
    setFragile(true);
}

FunctionHintProposal::~FunctionHintProposal() = default;

ProposalModelPtr FunctionHintProposal::model() const
{
    return m_model;
}

IAssistProposalWidget *FunctionHintProposal::createWidget() const
{
    return new FunctionHintProposalWidget;
}
